@@ -4,8 +4,10 @@ use strict;
 use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI';
 use mro 'c3';
+use Carp::Clan qw/^DBIx::Class/;
+use namespace::clean;
 
-our $VERSION = '0.07048_01';
+our $VERSION = '0.07008';
 
 =head1 NAME
 
@@ -20,21 +22,27 @@ See L<DBIx::Class::Schema::Loader::Base> for usage information.
 =cut
 
 sub _rebless {
-    my $self = shift;
+  my $self = shift;
 
-    return if ref $self ne __PACKAGE__;
+  return if ref $self ne __PACKAGE__;
 
-    my $dbh  = $self->schema->storage->dbh;
-    my $dbtype = eval { $dbh->get_info(17) };
-    unless ( $@ ) {
-        # Translate the backend name into a perl identifier
-        $dbtype =~ s/\W/_/gi;
-        my $class = "DBIx::Class::Schema::Loader::DBI::ADO::${dbtype}";
-        if ($self->load_optional_class($class) && !$self->isa($class)) {
-            bless $self, $class;
-            $self->_rebless;
-        }
+  my $dbh  = $self->schema->storage->dbh;
+  my $dbtype = eval { $dbh->get_info(17) };
+  unless ( $@ ) {
+    # Translate the backend name into a perl identifier
+    $dbtype =~ s/\W/_/gi;
+    my $class = "DBIx::Class::Schema::Loader::DBI::ADO::${dbtype}";
+    if ($self->load_optional_class($class) && !$self->isa($class)) {
+        bless $self, $class;
+        $self->_rebless;
     }
+  }
+}
+
+sub _tables_list {
+    my ($self, $opts) = @_;
+
+    return $self->next::method($opts, undef, undef);
 }
 
 sub _filter_tables {
@@ -52,9 +60,9 @@ L<DBIx::Class::Schema::Loader::DBI::ADO::MS_Jet>,
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-See L<DBIx::Class::Schema::Loader/AUTHORS>.
+See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
 
 =head1 LICENSE
 
