@@ -7,10 +7,11 @@ use base qw/
     DBIx::Class::Schema::Loader::DBI::ODBC::ACCESS
 /;
 use mro 'c3';
+use Carp::Clan qw/^DBIx::Class/;
 use Try::Tiny;
 use namespace::clean;
 
-our $VERSION = '0.07048_01';
+our $VERSION = '0.07008';
 
 =head1 NAME
 
@@ -123,7 +124,23 @@ sub _columns_info_for {
     while (my ($col, $info) = each %$result) {
         my $data_type = $info->{data_type};
 
-        my $col_obj = $self->_adox_column($table, $col);
+        my $col_obj;
+
+        $self->_adox_catalog->Tables->Item($table)->Columns;
+
+        for my $col_idx (0..$cols->Count-1) {
+            $col_obj = $cols->Item($col_idx);
+            if ($self->preserve_case) {
+                last if $col_obj->Name eq $col;
+            }
+            else {
+                last if lc($col_obj->Name) eq lc($col);
+            }
+        }
+
+        if ($col_obj->Attributes | 2 == 2) {
+            $info->{is_nullable} = 1;
+        }
 
         if ($data_type eq 'long') {
             $info->{data_type} = 'integer';
@@ -177,6 +194,7 @@ sub _columns_info_for {
                     $info->{data_type} = 'binary';
                     last;
                 }
+
             }
 
             $info->{size} = $col_obj->DefinedSize;
@@ -198,9 +216,9 @@ L<DBIx::Class::Schema::Loader::DBI::ADO>,
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-See L<DBIx::Class::Schema::Loader/AUTHORS>.
+See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
 
 =head1 LICENSE
 
