@@ -7,11 +7,10 @@ use base qw/
     DBIx::Class::Schema::Loader::DBI::MSSQL
 /;
 use mro 'c3';
-use DBIx::Class::Schema::Loader::Utils qw/sigwarn_silencer/;
-
+use Carp::Clan qw/^DBIx::Class/;
 use namespace::clean;
 
-our $VERSION = '0.07048_01';
+our $VERSION = '0.07008';
 
 =head1 NAME
 
@@ -24,25 +23,15 @@ Proxy for L<DBIx::Class::Schema::Loader::DBI::MSSQL> when using L<DBD::ADO>.
 
 See L<DBIx::Class::Schema::Loader::Base> for usage information.
 
-=cut
-
-# Silence ADO "Changed database context" warnings
-sub _switch_db {
-    my $self = shift;
-    local $SIG{__WARN__} = sigwarn_silencer(qr/Changed database context/);
-    return $self->next::method(@_);
-}
-
 =head1 SEE ALSO
 
-L<DBIx::Class::Schema::Loader::DBI::ADO>,
 L<DBIx::Class::Schema::Loader::DBI::MSSQL>,
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-See L<DBIx::Class::Schema::Loader/AUTHORS>.
+See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
 
 =head1 LICENSE
 
